# Note that each entity should only appear once - if a entity is updated
# twice, then the earlier update should just be removed from this list
data modify storage mver:update entities set value []
data modify storage mver:update villagers set value {}

# Entities which should be updated seperately from rooms, either since they 
# require extra processing (i.e. villagers), or they should be room-independent
#
# Format:
#   type: str -> the entity type (namespaced ID)
#   posX, posY, posZ: double -> the position to summon the entity at.
#   min_compatible: int -> the version this entity was implemented/ last updated in
#                     If the current world version is less than or equal to this value, then the entity will be summoned
#   max_compatible: int -> the version this entity was last used in
#                     If the current world version is greater than this value, then the entity will be killed
#   entity_tag: str -> the unique entity tag used in identifying this entity
#   entity_data: compound -> the entity data to be merged to the summon entity
#                            This should be in the same format as if input to the summon command
#
#   villager_tag: (optional) str -> the id used in getting the trade data from the villager data defined in storage
#   score_req: (optional) str -> the dummy score holder (in the MVER_Unlocks scoreboard) used to determine whether to summon this entity 
#                                (assuming a valid version)
#   score_check: (optional) int -> checks for a specific unlock value | defaults to "1"
#   score_cond: (optional) str -> "unless" or "if", as to how the match fails | defaults to "if"

data modify storage mver:update entities append value {type: "minecraft:text_display", posX: 0.5d, posY: 28d, posZ: 4.5d, min_compatible: 0, entity_tag: "birch_tier_setup", entity_data: {billboard:"vertical",text:'{"bold":true,"color":"red","text":"Set Birch Tier as Active"}'}, score_req: "activetier", score_check: "1", score_cond: "unless", is_single:1b}
# data modify storage mver:update entities append value {type: "minecraft:text_display", posX: 0.5d, posY: 28d, posZ: 3.5d, min_compatible: 0, entity_tag: "bamboo_tier_setup", entity_data: {billboard:"vertical",text:'{"bold":true,"color":"red","text":"Set Bamboo Tier as Active"}'}, score_req: "activetier", score_check: "2", score_cond: "unless", is_single:1b}

data modify storage mver:update entities append value {type: "minecraft:text_display", posX: -7.5d, posY: 27d, posZ: 7.5d, min_compatible: 0, entity_tag: "achievement_coming_soon", entity_data: {billboard:"vertical",text:'{"bold":true,"color":"dark_aqua","text":"Coming Very Soon :D"}'}}
data modify storage mver:update entities append value {type: "minecraft:text_display", posX: 8.5d, posY: 27d, posZ: -6.5d, min_compatible: 0, entity_tag: "battleground_coming_soon", entity_data: {billboard:"vertical",text:'{"bold":true,"color":"dark_aqua","text":"Coming Decently Soon :)"}'}}
data modify storage mver:update entities append value {type: "minecraft:text_display", posX: -7.5d, posY: 27d, posZ: -6.5d, min_compatible: 2, entity_tag: "time_hall_coming_soon", entity_data: {billboard:"vertical",text:'{"bold":true,"color":"dark_aqua","text":"Coming Less Soon :|"}'}}


# Removal Entities
data modify storage mver:update entities append value {type: "minecraft:text_display", posX: 0.5d, posY: 28d, posZ: -3.5d, min_compatible: 0, entity_tag: "helper_coming_soon", entity_data: {billboard:"vertical",text:'{"bold":true,"color":"dark_aqua","text":"Coming Very Soon :D"}'}}
data modify storage mver:update entities append value {type: "minecraft:text_display", posX: 8.5d, posY: 27d, posZ: 7.5d, min_compatible: 0, entity_tag: "bank_coming_soon", entity_data: {billboard:"vertical",text:'{"bold":true,"color":"dark_aqua","text":"Coming Very Soon :D"}'}}


data modify storage mver:update entities append value {\
  type: "minecraft:villager", posX: -3.5d, posY: 27d, posZ: 0.5d, min_compatible: 2, entity_tag: "birch_smeltery", \
  entity_data: {OnGround:1b,Silent:1b,Invulnerable:1b,CustomNameVisible:1b,PersistenceRequired:1b,NoAI:1b,Rotation:[-90F,0F],CustomName:'{"text":"The Birch Smeltery","color":"dark_purple","bold":true,"italic":false,"underlined":false,"strikethrough":false,"obfuscated":false}'}, \
  villager_tag: "birch_smeltery_data", score_req: "$birch_smeltery"}
data modify storage mver:update entities append value {\
  type: "minecraft:villager", posX: 4.5d, posY: 27d, posZ: 0.5d, min_compatible: 0, entity_tag: "birch_axeshop", \
  entity_data: {OnGround:1b,Silent:1b,Invulnerable:1b,CustomNameVisible:1b,PersistenceRequired:1b,NoAI:1b,Rotation:[90F,0F],CustomName:'{"text":"The Birch Axeshop","color":"dark_purple","bold":true,"italic":false,"underlined":false,"strikethrough":false,"obfuscated":false}'}, \
  villager_tag: "birch_axeshop_data", score_req: "$birch_axeshop"}
# data modify storage mver:update entities append value {\
#  type: "minecraft:villager", posX: 0.5d, posY: 27d, posZ: -4.5d, min_compatible: 3, entity_tag: "birch_jobcenter", \
#  entity_data: {OnGround:1b,Silent:1b,Invulnerable:1b,CustomNameVisible:1b,PersistenceRequired:1b,NoAI:1b,Rotation:[0F,90F],CustomName:'{"text":"The Birch Job Center","color":"dark_purple","bold":true,"italic":false,"underlined":false,"strikethrough":false,"obfuscated":false}'}, \
#  villager_tag: "birch_jobcenter_data", score_req: "$birch_jobcenter"}


# Villager trade data, used for villagers which need to pull their trade data from loot tables
#
# Format:
#   profession: str -> the villager profession (namespaced ID)
#   level: int -> the villager level to display in the badge/name
#
#   trades: array -> holds a list of compounds defining the trades for that villager, in the following format
#   {
#       buy: compound -> the first item the villager requires in order to trade
#       {
#         type: enum - "item"/"loot_table" -> the type of data in the `value` field
#         value: str ->
#           if type: "item" -> the item (namespaced ID)
#           if type: "loot_table" -> the loot table (namespaced ID)
#         count: int -> the count for the item
#       }
#       buyB: compound (optional) -> the second item the villager requires in order to trade
#         (Same format as above)
#       sell: compound -> the item the villager sells
#         (Same format as above)
#
#       maxCountFlag: str -> the score holder in the MVR_Unlocks scoreboard which signifies this trade has been completely used up
#         (when set to 1)
#       maxCount: int -> the number of trades which should be allowed
#   }

data modify storage mver:update villagers.birch_smeltery_data merge value {\
  profession: "minecraft:weaponsmith", level: 5, \
  trades: [\
    {buy: {type: "loot_table", value: "birch_tier:currency/birch_wood", count: 45}, sell: {type: "loot_table", value: "birch_tier:currency/processed_birch_wood", count: 1}},\
    {buy: {type: "loot_table", value: "birch_tier:currency/processed_birch_wood", count: 99}, sell: {type: "loot_table", value: "birch_tier:currency/birch_planks", count: 1}},\
    {buy: {type: "loot_table", value: "birch_tier:currency/birch_planks", count: 99}, buyB: {type: "loot_table", value: "birch_tier:currency/birch_planks", count: 45}, sell: {type: "loot_table", value: "birch_tier:currency/compressed_birch_planks", count: 1}},\
    {buy: {type: "loot_table", value: "birch_tier:currency/compressed_birch_planks", count: 99}, buyB: {type: "loot_table", value: "birch_tier:currency/compressed_birch_planks", count: 99}, sell: {type: "loot_table", value: "birch_tier:currency/crafting/powder", count: 1}},\
    {buy: {type: "loot_table", value: "birch_tier:currency/crafting/powder", count: 99}, buyB: {type: "loot_table", value: "birch_tier:currency/crafting/powder", count: 99}, sell: {type: "loot_table", value: "birch_tier:currency/crafting/essence", count: 1}},\
    {buy: {type: "loot_table", value: "birch_tier:currency/crafting/essence", count: 99}, buyB: {type: "loot_table", value: "birch_tier:currency/crafting/essence", count: 99}, sell: {type: "loot_table", value: "birch_tier:currency/crafting/enzyme", count: 1}},\
    {buy: {type: "loot_table", value: "birch_tier:currency/crafting/enzyme", count: 99}, buyB: {type: "loot_table", value: "birch_tier:currency/crafting/enzyme", count: 99}, sell: {type: "loot_table", value: "birch_tier:currency/crafting/extract", count: 1}},\
    {buy: {type: "loot_table", value: "birch_tier:currency/crafting/extract", count: 99}, buyB: {type: "loot_table", value: "birch_tier:currency/villager/crafting/extract", count: 99}, sell: {type: "loot_table", value: "birch_tier:currency/crafting/concentrate", count: 1}},\
    {buy: {type: "loot_table", value: "birch_tier:currency/crafting/concentrate", count: 99}, buyB: {type: "loot_table", value: "birch_tier:currency/crafting/concentrate", count: 99}, sell: {type: "loot_table", value: "birch_tier:currency/crafting/chunk", count: 1}},\
    {buy: {type: "loot_table", value: "birch_tier:currency/crafting/chunk", count: 99}, buyB: {type: "loot_table", value: "birch_tier:currency/crafting/chunk", count: 99}, sell: {type: "loot_table", value: "birch_tier:items/temporal_key", count: 1}, maxCount: 1, maxCountFlag: "$birch_temporal_key"}\
  ]}

data modify storage mver:update villagers.birch_axeshop_data merge value {\
  profession: "minecraft:toolsmith", level: 5, \
  trades: [\
    {buy: {type: "loot_table", value: "birch_tier:currency/birch_wood", count: 30}, sell: {type: "loot_table", value: "birch_tier:tools/basic_birch_axe", count: 1}},\
    {buy: {type: "loot_table", value: "birch_tier:currency/processed_birch_wood", count: 2}, buyB: {type: "loot_table", value: "birch_tier:currency/birch_wood", count: 13}, sell: {type: "loot_table", value: "birch_tier:tools/simplistic_birch_slicer_axe", count: 1}},\
    {buy: {type: "loot_table", value: "birch_tier:currency/processed_birch_wood", count: 48}, buyB: {type: "loot_table", value: "birch_tier:currency/birch_wood", count: 86}, sell: {type: "loot_table", value: "birch_tier:tools/birch_carver_axe", count: 1}}\
  ]}

#data modify storage mver:update villagers.birch_jobcenter_data merge value {\
#  profession: "minecraft:toolsmith", level: 5, \
#  trades: [\
#    {buy: {type: "loot_table", value: "birch_tier:currency/processed_birch_wood", count: 2}, buyB: {type: "loot_table", value: "birch_tier:currency/birch_wood", count: 13}, sell: {type: "loot_table", value: "birch_tier:tools/simplistic_birch_slicer_axe", count: 1}}\
#  ]}